## 3.2.2 (2021-10-12)

Add star to all non-0.1 versions (#6146)

## 3.2.1 (2021-09-20)

ttkthemes: allow constructing ThemedStyle with no arguments (#6046)

## 3.2.0 (2021-09-10)

Stubs for ttkthemes (#6024)

